#ifndef zetsubou_FitFunctionDef
#define zetsubou_FitFunctionDef
//definision of fit function

//expression of single gaussian 
Double_t singlegaussian(Double_t *x, Double_t *par)
{
  Double_t fitval = par[0]/(sqrt(2.*TMath::Pi())*par[2])*TMath::Exp(-(x[0]-par[1])*(x[0]-par[1])/2./par[2]/par[2]);
  return fitval;
}

//expression of single gaussian + linear
Double_t singlegaussian_linear(Double_t *x, Double_t *par)
{
 Double_t fitval = par[0]/(sqrt(2.*TMath::Pi())*par[2])*TMath::Exp(-(x[0]-par[1])*(x[0]-par[1])/2./par[2]/par[2])
                       + par[3]*x[0]+par[4];
 return fitval;
}

//expresion of double gaussian 
Double_t doublegaussian(Double_t *x, Double_t *par)
{
   Double_t fitval = par[0]/(sqrt(2.*TMath::Pi())*par[2])*TMath::Exp(-(x[0]-par[1])*(x[0]-par[1])/2./par[2]/par[2])
                         + par[3]/(sqrt(2.*TMath::Pi())*par[5])*TMath::Exp(-(x[0]-par[4])*(x[0]-par[4])/2./par[5]/par[5]);
  return fitval;
}

//expresion of double gaussian +linear
Double_t doublegaussian_linear(Double_t *x, Double_t *par)
{
  Double_t fitval = par[0]/(sqrt(2.*TMath::Pi())*par[2])*TMath::Exp(-(x[0]-par[1])*(x[0]-par[1])/2./par[2]/par[2])
                        + par[3]/(sqrt(2.*TMath::Pi())*par[5])*TMath::Exp(-(x[0]-par[4])*(x[0]-par[4])/2./par[5]/par[5])
                        + par[6]*x[0]+par[7];
  return fitval;
}

//expresion of triple gaussian
Double_t triplegaussian(Double_t *x, Double_t *par)
{
  Double_t fitval =par[0]/(sqrt(2.*TMath::Pi())*par[2])*TMath::Exp(-(x[0]-par[1])*(x[0]-par[1])/2./par[2]/par[2])
                        +par[3]/(sqrt(2.*TMath::Pi())*par[5])*TMath::Exp(-(x[0]-par[4])*(x[0]-par[4])/2./par[5]/par[5])
                        +par[6]/(sqrt(2.*TMath::Pi())*par[8])*TMath::Exp(-(x[0]-par[7])*(x[0]-par[7])/2./par[8]/par[8]);
  return fitval;
}

//expression of triple gaussian + linear
Double_t triplegaussian_linear(Double_t *x, Double_t *par)
{
  Double_t fitval =par[0]/(sqrt(2.*TMath::Pi())*par[2])*TMath::Exp(-(x[0]-par[1])*(x[0]-par[1])/2./par[2]/par[2])
                        +par[3]/(sqrt(2.*TMath::Pi())*par[5])*TMath::Exp(-(x[0]-par[4])*(x[0]-par[4])/2./par[5]/par[5])
                        +par[6]/(sqrt(2.*TMath::Pi())*par[8])*TMath::Exp(-(x[0]-par[7])*(x[0]-par[7])/2./par[8]/par[8])
                        +par[9]*x[0]+par[10];
  return fitval;
}

//Convoluted Landau and Gaussian Fitting Function
Double_t langaufun(Double_t *x, Double_t *par)
{
  // Numeric constants
  Double_t invsq2pi = 0.3989422804014;   // (2 pi)^(-1/2)
  Double_t mpshift  = -0.22278298;       // Landau maximum location
  
  // Control constants
  Double_t np = 100.0;      // number of convolution steps
  Double_t sc =   5.0;      // convolution extends to +-sc Gaussian sigmas
  
  // Variables
  Double_t xx;
  Double_t mpc;
  Double_t fland;
  Double_t sum = 0.0;
  Double_t xlow,xupp;
  Double_t step;
  Double_t i;

  // MP shift correction
  mpc = par[1] - mpshift * par[0]; 

  // Range of convolution integral
  xlow = x[0] - sc * par[3];
  xupp = x[0] + sc * par[3];

  step = (xupp-xlow) / np;

  // Convolution integral of Landau and Gaussian by sum
  for(i=1.0; i<=np/2; i++) 
  {
  xx = xlow + (i-.5) * step;
  fland = TMath::Landau(xx,mpc,par[0]) / par[0];
  sum += fland * TMath::Gaus(x[0],xx,par[3]);

  xx = xupp - (i-.5) * step;
  fland = TMath::Landau(xx,mpc,par[0]) / par[0];
  sum += fland * TMath::Gaus(x[0],xx,par[3]);
  }

  return (par[2] * step * sum * invsq2pi / par[3]);
}
#endif //FitFunctionDef.h
